.. _topics-index:

==============================
pythonbible |version| documentation
==============================

pythonbible includes features for parsing texts for scripture references,
converting references into integer verse ids for efficient use/storage,
converting verse ids back into normalized references, and formatting
references as human-readable strings.

Getting help
============

Having trouble? We'd like to help!

* Report bugs with pythonbible in our `issue tracker`_.

.. _issue tracker: https://github.com/avendesora/python-bible/issues

First steps
===========

.. toctree::
   :caption: First steps
   :hidden:

   intro/overview
   intro/install
   intro/tutorial

:doc:`intro/overview`
    Understand what pythonbible is and how it can help you.

:doc:`intro/install`
    Get pythonbible installed.

:doc:`intro/tutorial`
    How to use pythonbible.
